<?php

namespace Drupal\social_auth\Plugin\Network;

use Drupal\Core\Url;
use Drupal\social_api\Plugin\NetworkInterface as NetworkInterfaceBase;

/**
 * Defines an interface for Social Auth Network.
 */
interface NetworkInterface extends NetworkInterfaceBase {

  /**
   * Gets the network's redirect URL.
   *
   * @param array $route_options
   *   Additional options for the route.
   *
   * @return \Drupal\Core\Url
   *   Redirect URL for the network.
   */
  public function getRedirectUrl(array $route_options = []): Url;

  /**
   * Gets the network's callback URL.
   *
   * @param array $route_options
   *   Additional options for the route.
   *
   * @return \Drupal\Core\Url
   *   Callback URL for the network.
   */
  public function getCallbackUrl(array $route_options = []): Url;

  /**
   * Gets the network's settings form URL.
   *
   * @param array $route_options
   *   Additional options for the route.
   *
   * @return \Drupal\Core\Url
   *   Settings URL for the network.
   */
  public function getSettingsFormUrl(array $route_options = []): Url;

  /**
   * Gets the full path of the provider logo for the network.
   *
   * This path is used to render log in buttons with images in the provided
   * login block.
   *
   * @return string
   *   Full path to the network logo.
   *
   * @see \Drupal\social_auth\Plugin\Block\SocialAuthLoginBlock
   */
  public function getProviderLogoPath(): string;

}
